@@ -68,12 +68,16 @@
 #' @return babelmixr2 control option for generating NONMEM control stream and
 #'   reading it back into `babelmixr2`/`nlmixr2`
 #'
+#' @inheritParams nlmixr2est::saemControl
+#'
 #' @author Matthew L. Fidler
 #'
 #' @export
 #'
 #' @examples
+#'
 #' nonmemControl()
+#'
 nonmemControl <- function(est=c("focei", "imp", "its", "posthoc"),
                           advanOde=c("advan13", "advan8", "advan6"),
                           cov=c("r,s", "r", "s", ""),
@@ -112,6 +116,7 @@ nonmemControl <- function(est=c("focei", "imp", "its", "posthoc"),
                           mapinter=0,
                           noabort=TRUE,
                           modelName=NULL,
+                          muRefCovAlg=TRUE,
                           ...) {
   # nonmem manual slides suggest tol=6, sigl=6 sigdig=2
   checkmate::assertIntegerish(maxeval, lower=100, len=1, any.missing=FALSE)
@@ -136,6 +141,7 @@ nonmemControl <- function(est=c("focei", "imp", "its", "posthoc"),
   checkmate::assertNumeric(df, lower=0, len=1, any.missing=FALSE)
   checkmate::assertIntegerish(seed, lower=1, len=1, any.missing=FALSE)
   checkmate::assertIntegerish(mapiter, len=1, any.missing=FALSE)
+  checkmate::assertLogical(muRefCovAlg, any.missing=FALSE, len=1)
   if (!is.null(modelName)) {
     checkmate::assertCharacter(modelName, len=1, any.missing=FALSE)
   }
@@ -172,6 +178,7 @@ nonmemControl <- function(est=c("focei", "imp", "its", "posthoc"),
         ssRtol=10^(-sstol),
         ssAtol=10^(-ssatol),
         covsInterpolation="nocb",
+        safeZero=FALSE,
         method="liblsoda"
       )
       genRxControl <- TRUE
@@ -182,6 +189,7 @@ nonmemControl <- function(est=c("focei", "imp", "its", "posthoc"),
       rxControl$ssAtol <- 10^(-ssatol)
       rxControl$covsInterpolation <- "nocb"
       rxControl$method <- "liblsoda"
+      rxControl$safeZero <- FALSE
       rxControl <- do.call(rxode2::rxControl, rxControl)
     }
     if (!inherits(rxControl, "rxControl")) {
@@ -231,7 +239,8 @@ nonmemControl <- function(est=c("focei", "imp", "its", "posthoc"),
                df=df,
                seed=seed,
                mapiter=mapiter,
-               modelName=modelName
+               modelName=modelName,
+               muRefCovAlg=muRefCovAlg
                )
   class(.ret) <- "nonmemControl"
   .ret
